diff mbox series

libcody: Fix typos

Message ID 20240918195056.11485-1-algonell@gmail.com
State New
Headers show
Series libcody: Fix typos | expand

Commit Message

Andrew Kreimer Sept. 18, 2024, 7:50 p.m. UTC
Fix typos in comments.

Signed-off-by: Andrew Kreimer <algonell@gmail.com>
---
 libcody/README.md |  2 +-
 libcody/cody.hh   | 14 +++++++-------
 2 files changed, 8 insertions(+), 8 deletions(-)
diff mbox series

Patch

diff --git a/libcody/README.md b/libcody/README.md
index a95085eac7a..4530db95d28 100644
--- a/libcody/README.md
+++ b/libcody/README.md
@@ -181,7 +181,7 @@  omitted the value 0 is implied.  The following flags are available:
 * `1<<0`, `NameOnly`: The request is for the name only, and not the
   CMI contents.
 
-The `NameOnly` flag may be provded in a handshake response, and
+The `NameOnly` flag may be provided in a handshake response, and
 indicates that the server is interested in requests only for their
 implied dependency information.  It may be provided on a request to
 indicate that only the CMI name is required, not its contents (for
diff --git a/libcody/cody.hh b/libcody/cody.hh
index 789ce9e70b7..5473b3fe3c1 100644
--- a/libcody/cody.hh
+++ b/libcody/cody.hh
@@ -60,7 +60,7 @@  class MessageBuffer
 {
   std::vector<char> buffer;  ///< buffer holding the message
   size_t lastBol = 0;  ///< location of the most recent Beginning Of
-		       ///< Line, or position we've readed when writing
+		       ///< Line, or position we've read when writing
 
 public:
   MessageBuffer () = default;
@@ -382,7 +382,7 @@  private:
     Server *server;  ///< Directly connected server
   };
   bool is_direct = false;  ///< Discriminator
-  bool is_connected = false;  /// Connection handshake succesful
+  bool is_connected = false;  /// Connection handshake successful
 
 private:
   Client ();
@@ -448,8 +448,8 @@  public:
 
 public:
   ///
   /// Perform connection handshake.  All othe requests will result in
   /// errors, until handshake is succesful.
   /// @param agent compiler identification
   /// @param ident compilation identifiation (maybe nullptr)
   /// @param alen length of agent string, if known
@@ -507,7 +507,7 @@  public:
 
 public:
   /// Successful compilation of a module interface, partition or
-  /// header-unit.  Must have been preceeded by a ModuleExport
+  /// header-unit.  Must have been preceded by a ModuleExport
   /// request.
   /// @param str module or header-unit
   /// @param len name length, if known
@@ -698,7 +698,7 @@  public:
 public:
   /// Process requests from a directly-connected client.  This is a
   /// small wrapper around ProcessRequests, with some buffer swapping
-  /// for communication.  It is expected that such processessing is
+  /// for communication.  It is expected that such processing is
   /// immediate.
   /// @param from message block from client
   /// @param to message block to client
@@ -756,7 +756,7 @@  public:
     return write.Write (fd.to);
   }
   /// Initialize for writing a message block.  All responses to the
-  /// incomping message block must be complete  Enters WRITING state.
+  /// incoming message block must be complete  Enters WRITING state.
   void PrepareToWrite ()
   {
     write.PrepareToWrite ();
@@ -448,8 +448,8 @@  public:
 public:
   ///
-  /// Perform connection handshake.  All othe requests will result in
-  /// errors, until handshake is succesful.
+  /// Perform connection handshake.  All other requests will result in
+  /// errors, until handshake is successful.
   /// @param agent compiler identification
   /// @param ident compilation identifiation (maybe nullptr)